==> haskell-http2-1.6.3-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http2.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http2
version: 1.6.3
id: http2-1.6.3-9UVL3uhiG5pHMslzzrNTkR
key: http2-1.6.3-9UVL3uhiG5pHMslzzrNTkR
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: https://github.com/kazu-yamamoto/http2
synopsis: HTTP/2 library including frames, priority queues and HPACK
description:
    HTTP/2 library including frames, priority queues and HPACK.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
indefinite: False
exposed-modules:
    Network.HPACK Network.HPACK.Token Network.HTTP2
    Network.HTTP2.Priority
hidden-modules: Network.HPACK.Buffer Network.HPACK.Builder
                Network.HPACK.Huffman Network.HPACK.Huffman.Bit
                Network.HPACK.Huffman.ByteString Network.HPACK.Huffman.Decode
                Network.HPACK.Huffman.Encode Network.HPACK.Huffman.Params
                Network.HPACK.Huffman.Table Network.HPACK.Huffman.Tree
                Network.HPACK.HeaderBlock Network.HPACK.HeaderBlock.Decode
                Network.HPACK.HeaderBlock.Encode Network.HPACK.HeaderBlock.Integer
                Network.HPACK.Table Network.HPACK.Table.Dynamic
                Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
                Network.HPACK.Table.Static Network.HPACK.Types Network.HTTP2.Decode
                Network.HTTP2.Encode Network.HTTP2.Priority.PSQ
                Network.HTTP2.Priority.Queue Network.HTTP2.Types
abi: f5a45a4a29a3a43ab4b7e57e5b77db3e
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/http2-1.6.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/http2-1.6.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/http2-1.6.3
hs-libraries: HShttp2-1.6.3-9UVL3uhiG5pHMslzzrNTkR
depends:
    base-4.10.0.0 array-0.5.2.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI containers-0.5.10.2
    psqueues-0.2.4.0-F00pVfPVt6dDn5IhRLjD8k
    stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             array-0.5.2.0=5abf025fb7bf60079ec1f42bab285152
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=f9fb05439242cab6e496c322f2a1e33a
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
             psqueues-0.2.4.0-F00pVfPVt6dDn5IhRLjD8k=52343e94f6fed6db09133552e9eb96c4
             stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ=a88f5bbac4be96a38c5ca2a658c158a0
haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html: /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http2-1.6.3-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http2.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http2
version: 1.6.3
id: http2-1.6.3-8BE6Siwfbn2DeOxxzryzrS
key: http2-1.6.3-8BE6Siwfbn2DeOxxzryzrS
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: https://github.com/kazu-yamamoto/http2
synopsis: HTTP/2 library including frames, priority queues and HPACK
description:
    HTTP/2 library including frames, priority queues and HPACK.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
indefinite: False
exposed-modules:
    Network.HPACK Network.HPACK.Token Network.HTTP2
    Network.HTTP2.Priority
hidden-modules: Network.HPACK.Buffer Network.HPACK.Builder
                Network.HPACK.Huffman Network.HPACK.Huffman.Bit
                Network.HPACK.Huffman.ByteString Network.HPACK.Huffman.Decode
                Network.HPACK.Huffman.Encode Network.HPACK.Huffman.Params
                Network.HPACK.Huffman.Table Network.HPACK.Huffman.Tree
                Network.HPACK.HeaderBlock Network.HPACK.HeaderBlock.Decode
                Network.HPACK.HeaderBlock.Encode Network.HPACK.HeaderBlock.Integer
                Network.HPACK.Table Network.HPACK.Table.Dynamic
                Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
                Network.HPACK.Table.Static Network.HPACK.Types Network.HTTP2.Decode
                Network.HTTP2.Encode Network.HTTP2.Priority.PSQ
                Network.HTTP2.Priority.Queue Network.HTTP2.Types
abi: 3a098d36509297a5f9d8711ea45c2702
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/http2-1.6.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/http2-1.6.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/http2-1.6.3
hs-libraries: HShttp2-1.6.3-8BE6Siwfbn2DeOxxzryzrS
depends:
    base-4.10.1.0 array-0.5.2.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.10-BoRVwnTiXXU9RJ6NEnu1BA
    containers-0.5.10.2 psqueues-0.2.4.0-7bKOn0sHYQ7I0dykhI9bWo
    stm-2.4.4.1-E6EjE1bszQZJ9orPdUNxjw
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             case-insensitive-1.2.0.10-BoRVwnTiXXU9RJ6NEnu1BA=4295449faa2e312746ed6e93c93f9c1e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             psqueues-0.2.4.0-7bKOn0sHYQ7I0dykhI9bWo=9d2c6133824068b7a20b0fc65dff5f01
             stm-2.4.4.1-E6EjE1bszQZJ9orPdUNxjw=63c518eabfb1b430d925fb35cc544a7c
haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html: /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
